==> FHLBBS-5.1.tgz: php/useredit.php <==
<?php
/************ ͱKX ******/
function genpasswd($pw)
{
  if (strlen($pw)>0)
  {
    $i = 9 * getmypid()+time();
    $saltc[0] = $i & 077;
    $saltc[1] = ($i >> 6) & 077;

    for ($i = 0; $i < 2; $i++)
    {
      $c = $saltc[$i] + ord(".");
      if ($c > ord("9"))
        $c = $c+7;
      if ($c > ord("Z"))
        $c = $c+6;
      $saltc[$i] = $c;
    }
    $slat=chr($saltc[0]).chr($saltc[1]);
    $cpw=crypt($pw, $slat);
    return $cpw;
  }
  return "";
}

 require("config.php");
 require("wbbs.php");
 $flagx=substr($QUERY_STRING,0,1);
 if(strcmp($flagx,"n")!=0) //pGOsUλ{ҧYi
    require("auth.php");
 else
    require("record.php");
 session_register("userid","cuser","pwd");

    /**** קҦ ***/
   if(strcmp($flagx,"e")==0){
      if (strcasecmp($cuser->userid,"guest")==0)
	die("Guest קӤH");
      $sexx=$cuser->sex+1; 
     //edit user info form
     $genbuf=$DEFDIR[$doorid].$USEREDIT;

     if (($fp=fopen($genbuf,"r"))===false)
	die ("$genbuf }ҿ~I");
	 /*LXҪɮ **/
    while (!feof($fp))
    {
        $genbuf=fgets($fp,1000);
        $pt1=$genbuf;
        while (!(($pt2=strpos($pt1,"<!--$"))===false))
        {
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
                        die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else
            {
              /*** Bzradio ***/
              if($sexx == 1)
         	echo "<input type=\"radio\" checked value=\"1\" name=\"SEX\" ><small>&nbsp;</small>\n";
      	      else
         	echo "<input type=\"radio\" value=\"1\" name=\"SEX\" ><small>&nbsp;</small>\n";

      	      if($sexx == 2)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"2\"><small>j&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"2\"><small>j&nbsp;</small>";

      	      if($sexx == 3)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"3\"><small>}&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"3\"><small>}&nbsp;</small>";
      	      if($sexx == 4)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"4\"><small>&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"4\"><small>&nbsp;</small>";
      	      if($sexx == 5)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"5\"><small>&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"5\"><small>&nbsp;</small>";
      	      if($sexx == 6)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"6\"><small>&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"6\"><small>&nbsp;</small>";
      	      if($sexx == 7)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"7\"><small>Ӫ&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"7\"><small>Ӫ&nbsp;</small>";
      	      if($sexx == 8)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"8\"><small>q</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"8\"><small>q</small>";

            } //ptmode==0
     	} //while --> 
            echo $pt1;
       }// while read oneline
       fclose($fp);
       die("");
   } //flagx = "e"
   elseif((strcmp($flagx,"n")==0)){ //sU
      $cuser= new userrec;
      $cuser->userid=$_REQUEST["USER"];
      $userid=$cuser->userid;
      $cuser->username=$_REQUEST["ALIAS"];
      $cuser->realname=$_REQUEST["NAME"];
      $cuser->address=$_REQUEST["ADDRESS"];
      $cuser->email=$_REQUEST["EMAIL"];
      $cuser->year=$_REQUEST["YY"];
      $cuser->month=$_REQUEST["MM"];
      $cuser->day=$_REQUEST["DD"];
      $cuser->sex=(int) $_REQUEST["SEX"] -1;
      if ($cuser->sex < 0) $cuser->sex=0;
      elseif ($cuser->sex > 7) $cuser->sex=7;
       /*ˬdJ*/
      if (strlen($cuser->userid)<3)
	die("idӵuAݭnJ3ӦrHWI");
      if (strcasecmp($cuser->userid,"new")==0)
	die("iHϥ new oid!");
      if (ereg("^[[:alpha:]]([[:alnum:]]+)",$cuser->userid)==false)
	die("LkoӥNAШϥέ^rAåBn]tŮ<br>");
      if(searchuser($cuser->userid)>0)
        die("NwgHϥ!");
      $password1=$_REQUEST["PASSWORD1"];
      $password2=$_REQUEST["PASSWORD2"];
      if (strcmp($password1,$password2)!=0)
                die("շsKXkXI");
      if((strlen($password1) < 4) || (strcmp($password1, $cuser->userid)==0))
        die("KX²ADJIAܤ֭n 4 ӦrAЭsJ\n");
      $cuser->passwd=genpasswd($password1);
      $pwd=$password1;
      if(strlen($cuser->realname) < 4)
       	die ("DzmW֩ӦrH\n");
      if(strlen($cuser->address) < 8)
       	die ("Sou}aH\n");
      if(strpos($cuser->email, '@')===false || strlen($cuser.email)==0)
       	 die(" FzvqAжguꪺ E-mail addressAHT{դU\n");
      $today = getdate(); 
      if($cuser->month > 12 || $cuser->month < 1
         || $cuser->day > 31 || $cuser->day < 1 || $cuser->year<1910 ||
          $cuser->year>$today['year']-4)
       die ("ͤFI\n");
      $cuser->userlevel = PERM_DEFAULT; 
      $cuser->numlogins=0;
      $cuser->numposts=0;
      $cuser->uflag=COLOR_FLAG | BRDSORT_FLAG | MOVIE_FLAG;
      $cuser->firstlogin = $cuser->lastlogin = time();
      $allocid = searchnewuser();
      if ($allocid==0) die("ϥΪ̤wI");
      $cuser->substitute_record($PASSWD_FILE,$allocid);
      //٭nsJ share memory 
      shmputuser($allocid,$cuser->userid);
      /*****}ؿ*****/
      $genbuf=sethomepath($cuser->userid);
      if (mkdir($genbuf, 0755)==false) echo "}ϥΪ̥ؿѡI<br>";
      die("$cuser->userid U!<br><a href=\"/php/login.php\" target=\"_top\">ЫB~</a>I");
   }
   elseif((strcmp($flagx,"s")==0)){
      if (strcasecmp($cuser->userid,"guest")==0)
	die("Guest קӤH");
      // save user edit info to bbs server
      $cuser->username=$_REQUEST["ALIAS"];
      $cuser->realname=$_REQUEST["NAME"];
      $cuser->address=$_REQUEST["ADDRESS"];
      $cuser->email=$_REQUEST["EMAIL"];
      $cuser->year=$_REQUEST["YY"];
      $cuser->month=$_REQUEST["MM"];
      $cuser->day=$_REQUEST["DD"];
      $cuser->sex=(int) $_REQUEST["SEX"] -1;
      if ($cuser->sex < 0) $cuser->sex=0;
      elseif ($cuser->sex > 7) $cuser->sex=7;
      if(strlen($cuser->realname) < 4)
       	die ("DzmW֩ӦrH\n");
      if(strlen($cuser->address) < 8)
       	die ("Sou}aH\n");
      if(strpos($cuser->email, '@')===false || strlen($cuser.email)==0)
       	 die(" FzvqAжguꪺ E-mail addressAHT{դU\n");
      $today = getdate(); 
      if($cuser->month > 12 || $cuser->month < 1
         || $cuser->day > 31 || $cuser->day < 1 || $cuser->year<1910 ||
          $cuser->year>$today['year']-4)
       die ("ͤFI\n");
	$pag=(int) $_REQUEST["PAGER"];
	if ($pag==1) $cuser->uflag=$cuser->uflag & (!PAGER_FLAG) ;
        elseif ($pag==2) $cuser->uflag=$cuser->uflag | PAGER_FLAG ;

      $uid=searchuser($userid);
      $cuser->substitute_record($PASSWD_FILE,$uid);
      die("$cuser->userid ק粒!<br><a href=\"/php/login.php\" target=\"_top\">ЫB~</a>I");
   }
   elseif((strcmp($flagx,"p")==0)){
      if (strcasecmp($cuser->userid,"guest")==0)
	die("Guest קӤH");
      // confirm change password edit info, save new password to bbs server.
      $password=$_REQUEST["OLDPASS"];
      $password1=$_REQUEST["NEWPASS1"];
      $password2=$_REQUEST["NEWPASS2"];
      $auth_key = crypt($password, $cuser->passwd);
      if (strcmp($auth_key,$cuser->passwd)!=0)
	die("KX~IiOHKXI");

      if (strcmp($password1,$password2)!=0)
		die("շsKXkXI");
      if((strlen($password1) < 4) || (strcmp($password1, $cuser->userid)==0))
       	die("KX²ADJIAܤ֭n 4 ӦrAЭsJ\n");
   
      $cuser->passwd=genpasswd($password1);
      $uid=searchuser($userid);
      $cuser->substitute_record($PASSWD_FILE,$uid);

        echo "KXs\<br>";
	echo "<a href=\"/\"  target=\"_top\">BsηsKXi</a>";
      }
?>

==> FHLBBS-5.3.tgz: php/useredit.php <==
<?php
/************ ͱKX ******/
function genpasswd($pw)
{
  if (strlen($pw)>0)
  {
    $i = 9 * getmypid()+time();
    $saltc[0] = $i & 077;
    $saltc[1] = ($i >> 6) & 077;

    for ($i = 0; $i < 2; $i++)
    {
      $c = $saltc[$i] + ord(".");
      if ($c > ord("9"))
        $c = $c+7;
      if ($c > ord("Z"))
        $c = $c+6;
      $saltc[$i] = $c;
    }
    $slat=chr($saltc[0]).chr($saltc[1]);
    $cpw=crypt($pw, $slat);
    return $cpw;
  }
  return "";
}

 require("config.php");
 require("wbbs.php");
 $flagx=substr($QUERY_STRING,0,1);
 if(strcmp($flagx,"n")!=0) //pGOsUλ{ҧYi
    require("auth.php");
 else
    require("record.php");
 session_register("userid","cuser","pwd");

    /**** קҦ ***/
   if(strcmp($flagx,"e")==0){
      if (strcasecmp($cuser->userid,"guest")==0)
	die("Guest קӤH");
      $sexx=$cuser->sex+1; 
     //edit user info form
     $genbuf=$DEFDIR[$doorid].$USEREDIT;

     if (($fp=fopen($genbuf,"r"))===false)
	die ("$genbuf }ҿ~I");
	 /*LXҪɮ **/
    while (!feof($fp))
    {
        $genbuf=fgets($fp,1000);
        $pt1=$genbuf;
        while (!(($pt2=strpos($pt1,"<!--$"))===false))
        {
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
                        die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else
            {
              /*** Bzradio ***/
              if($sexx == 1)
         	echo "<input type=\"radio\" checked value=\"1\" name=\"SEX\" ><small>&nbsp;</small>\n";
      	      else
         	echo "<input type=\"radio\" value=\"1\" name=\"SEX\" ><small>&nbsp;</small>\n";

      	      if($sexx == 2)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"2\"><small>j&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"2\"><small>j&nbsp;</small>";

      	      if($sexx == 3)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"3\"><small>}&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"3\"><small>}&nbsp;</small>";
      	      if($sexx == 4)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"4\"><small>&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"4\"><small>&nbsp;</small>";
      	      if($sexx == 5)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"5\"><small>&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"5\"><small>&nbsp;</small>";
      	      if($sexx == 6)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"6\"><small>&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"6\"><small>&nbsp;</small>";
      	      if($sexx == 7)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"7\"><small>Ӫ&nbsp;</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"7\"><small>Ӫ&nbsp;</small>";
      	      if($sexx == 8)
              	echo "<input type=\"radio\" checked name=\"SEX\" value=\"8\"><small>q</small>";
      	      else
         	echo "<input type=\"radio\" name=\"SEX\" value=\"8\"><small>q</small>";

            } //ptmode==0
     	} //while --> 
            echo $pt1;
       }// while read oneline
       fclose($fp);
       die("");
   } //flagx = "e"
   elseif((strcmp($flagx,"n")==0)){ //sU
      $cuser= new userrec;
      $cuser->userid=$_REQUEST["USER"];
      $userid=$cuser->userid;
      $cuser->username=$_REQUEST["ALIAS"];
      $cuser->realname=$_REQUEST["NAME"];
      $cuser->address=$_REQUEST["ADDRESS"];
      $cuser->email=$_REQUEST["EMAIL"];
      $cuser->year=$_REQUEST["YY"];
      $cuser->month=$_REQUEST["MM"];
      $cuser->day=$_REQUEST["DD"];
      $cuser->sex=(int) $_REQUEST["SEX"] -1;
      if ($cuser->sex < 0) $cuser->sex=0;
      elseif ($cuser->sex > 7) $cuser->sex=7;
       /*ˬdJ*/
      if (strlen($cuser->userid)<3)
	die("idӵuAݭnJ3ӦrHWI");
      if (strcasecmp($cuser->userid,"new")==0)
	die("iHϥ new oid!");
      if (ereg("^[[:alpha:]]([[:alnum:]]+)",$cuser->userid)===false)
	die("LkoӥNAШϥέ^rAåBn]tŮ<br>");
      if (ereg(" ",$cuser->userid)!==false)
	die("LkoӥNAШϥέ^rAåBn]tŮ<br>");
      if(searchuser($cuser->userid)>0)
        die("NwgHϥ!");
      $password1=$_REQUEST["PASSWORD1"];
      $password2=$_REQUEST["PASSWORD2"];
      if (strcmp($password1,$password2)!=0)
                die("շsKXkXI");
      if((strlen($password1) < 4) || (strcmp($password1, $cuser->userid)==0))
        die("KX²ADJIAܤ֭n 4 ӦrAЭsJ\n");
      $cuser->passwd=genpasswd($password1);
      $pwd=$password1;
      if(strlen($cuser->realname) < 4)
       	die ("DzmW֩ӦrH\n");
      if(strlen($cuser->address) < 8)
       	die ("Sou}aH\n");
      if(strpos($cuser->email, '@')===false || strlen($cuser.email)==0)
       	 die(" FzvqAжguꪺ E-mail addressAHT{դU\n");
      $today = getdate(); 
      if($cuser->month > 12 || $cuser->month < 1
         || $cuser->day > 31 || $cuser->day < 1 || $cuser->year<1910 ||
          $cuser->year>$today['year']-4)
       die ("ͤFI\n");
      $cuser->userlevel = PERM_DEFAULT; 
      $cuser->numlogins=0;
      $cuser->numposts=0;
      $cuser->uflag=COLOR_FLAG | BRDSORT_FLAG | MOVIE_FLAG;
      $cuser->firstlogin = $cuser->lastlogin = time();
      $allocid = searchnewuser();
      if ($allocid==0) die("ϥΪ̤wI");
      $cuser->substitute_record($PASSWD_FILE,$allocid);
      //٭nsJ share memory 
      shmputuser($allocid,$cuser->userid);
      /*****}ؿ*****/
      $genbuf=sethomepath($cuser->userid);
      if (mkdir($genbuf, 0755)===false) echo "}ϥΪ̥ؿѡI<br>";
      die("$cuser->userid U!<br><a href=\"/php/login.php\" target=\"_top\">ЫB~</a>I");
   }
   elseif((strcmp($flagx,"s")==0)){
      if (strcasecmp($cuser->userid,"guest")==0)
	die("Guest קӤH");
      // save user edit info to bbs server
      $cuser->username=$_REQUEST["ALIAS"];
      $cuser->realname=$_REQUEST["NAME"];
      $cuser->address=$_REQUEST["ADDRESS"];
      $cuser->email=$_REQUEST["EMAIL"];
      $cuser->year=$_REQUEST["YY"];
      $cuser->month=$_REQUEST["MM"];
      $cuser->day=$_REQUEST["DD"];
      $cuser->sex=(int) $_REQUEST["SEX"] -1;
      if ($cuser->sex < 0) $cuser->sex=0;
      elseif ($cuser->sex > 7) $cuser->sex=7;
      if(strlen($cuser->realname) < 4)
       	die ("DzmW֩ӦrH\n");
      if(strlen($cuser->address) < 8)
       	die ("Sou}aH\n");
      if(strpos($cuser->email, '@')===false || strlen($cuser.email)==0)
       	 die(" FzvqAжguꪺ E-mail addressAHT{դU\n");
      $today = getdate(); 
      if($cuser->month > 12 || $cuser->month < 1
         || $cuser->day > 31 || $cuser->day < 1 || $cuser->year<1910 ||
          $cuser->year>$today['year']-4)
       die ("ͤFI\n");
	$pag=(int) $_REQUEST["PAGER"];
	if ($pag==1) $cuser->uflag=$cuser->uflag & (!PAGER_FLAG) ;
        elseif ($pag==2) $cuser->uflag=$cuser->uflag | PAGER_FLAG ;

      $uid=searchuser($userid);
      $cuser->substitute_record($PASSWD_FILE,$uid);
      die("$cuser->userid ק粒!<br><a href=\"/php/login.php\" target=\"_top\">ЫB~</a>I");
   }
   elseif((strcmp($flagx,"p")==0)){
      if (strcasecmp($cuser->userid,"guest")==0)
	die("Guest קӤH");
      // confirm change password edit info, save new password to bbs server.
      $password=$_REQUEST["OLDPASS"];
      $password1=$_REQUEST["NEWPASS1"];
      $password2=$_REQUEST["NEWPASS2"];
      $auth_key = crypt($password, $cuser->passwd);
      if (strcmp($auth_key,$cuser->passwd)!=0)
	die("KX~IiOHKXI");

      if (strcmp($password1,$password2)!=0)
		die("շsKXkXI");
      if((strlen($password1) < 4) || (strcmp($password1, $cuser->userid)==0))
       	die("KX²ADJIAܤ֭n 4 ӦrAЭsJ\n");
   
      $cuser->passwd=genpasswd($password1);
      $uid=searchuser($userid);
      $cuser->substitute_record($PASSWD_FILE,$uid);

        echo "KXs\<br>";
	echo "<a href=\"/\"  target=\"_top\">BsηsKXi</a>";
      }
?>
